Class: Graph::Node
Overview
Nodes in the graph.
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
Attributes inherited from Thingy
Instance Method Summary collapse
-
#>>(name) ⇒ Object
(also: #<<)
Create a new node with
nameand an edge between them pointing from self to the new node. -
#[](dep_name) ⇒ Object
Returns the edge between self and
dep_name. - #connected? ⇒ Boolean
-
#initialize(graph, name) ⇒ Node
constructor
Create a new Node.
- #orphan? ⇒ Boolean
-
#to_s ⇒ Object
Returns the node in dot syntax.
Methods inherited from Thingy
#attributes?, #initialize_copy, #label
Constructor Details
#initialize(graph, name) ⇒ Node
Create a new Node. Takes a parent graph and a name.
514 515 516 517 |
# File 'lib/graph.rb', line 514 def initialize graph, name super graph self.name = name end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
499 500 501 |
# File 'lib/graph.rb', line 499 def name @name end |
Instance Method Details
#>>(name) ⇒ Object Also known as: <<
Create a new node with name and an edge between them pointing from self to the new node.
523 524 525 526 |
# File 'lib/graph.rb', line 523 def >> name self[name] # creates node and edge self end |
#[](dep_name) ⇒ Object
Returns the edge between self and dep_name.
533 534 535 |
# File 'lib/graph.rb', line 533 def [] dep_name graph.edges[name][dep_name] end |
#connected? ⇒ Boolean
501 502 503 504 505 |
# File 'lib/graph.rb', line 501 def connected? edges = graph.edges edges.include?(name) or edges.any? { |from, deps| deps.include? name } end |
#orphan? ⇒ Boolean
507 508 509 |
# File 'lib/graph.rb', line 507 def orphan? not connected? end |
#to_s ⇒ Object
Returns the node in dot syntax.
540 541 542 543 544 545 546 |
# File 'lib/graph.rb', line 540 def to_s if self.attributes? then "%-20p [ %-20s ]" % [name, attributes.join(',')] else "#{name.inspect}" end end |