Shortcut method to create a new font Attribute instance. You can pass in both the name and an optional font size.
291 292 293
# File 'lib/graph.rb', line 291 def font name Attribute.new "fontname = %p" % [name] end